==> haskell-skylighting-format-latex-0.1-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-2UA6PnNmtET8vt5yJ7Nwyg
key:                  skylighting-format-latex-0.1-2UA6PnNmtET8vt5yJ7Nwyg
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  871bf381af4439760ee0d44532e643a0
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-2UA6PnNmtET8vt5yJ7Nwyg
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-3e8cipH4j6z8CNzKRqRr4c text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-4zuU9MwfU80GO9RmaEJw3A
key:                  skylighting-format-latex-0.1-4zuU9MwfU80GO9RmaEJw3A
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  82838df2267829288a55218deea134b3
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-4zuU9MwfU80GO9RmaEJw3A
depends:
    base-4.17.2.1 containers-0.6.7
    skylighting-core-0.14.2-KEwPyQcCT4Q2NGI2D909V1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
